"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var coreutils_1 = require("@jupyterlab/coreutils");
var services_1 = require("@jupyterlab/services");
exports.GITHUB_API = 'https://api.github.com';
/**
 * Make a client-side request to the GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url).
 *
 * @returns a Promise resolved with the JSON response.
 */
function browserApiRequest(url) {
    var requestUrl = coreutils_1.URLExt.join(exports.GITHUB_API, url);
    return window.fetch(requestUrl).then(function (response) {
        if (response.status !== 200) {
            return response.json().then(function (data) {
                throw new services_1.ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
exports.browserApiRequest = browserApiRequest;
/**
 * Make a request to the notebook server proxy for the
 * GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url)
 *
 * @param settings - the settings for the current notebook server.
 *
 * @returns a Promise resolved with the JSON response.
 */
function proxiedApiRequest(url, settings) {
    var fullURL = coreutils_1.URLExt.join(settings.baseUrl, 'github', url);
    return services_1.ServerConnection.makeRequest(fullURL, {}, settings).then(function (response) {
        if (response.status !== 200) {
            return response.json().then(function (data) {
                throw new services_1.ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
exports.proxiedApiRequest = proxiedApiRequest;
/**
 * Typings representing contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/
 */
var GitHubContents = /** @class */ (function () {
    function GitHubContents() {
    }
    return GitHubContents;
}());
exports.GitHubContents = GitHubContents;
/**
 * Typings representing file contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-file
 */
var GitHubFileContents = /** @class */ (function (_super) {
    __extends(GitHubFileContents, _super);
    function GitHubFileContents() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GitHubFileContents;
}(GitHubContents));
exports.GitHubFileContents = GitHubFileContents;
/**
 * Typings representing a directory from the GitHub API v3.
 */
var GitHubDirectoryContents = /** @class */ (function (_super) {
    __extends(GitHubDirectoryContents, _super);
    function GitHubDirectoryContents() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GitHubDirectoryContents;
}(GitHubContents));
exports.GitHubDirectoryContents = GitHubDirectoryContents;
/**
 * Typings representing a blob from the GitHub API v3.
 * Cf: https://developer.github.com/v3/git/blobs/#response
 */
var GitHubBlob = /** @class */ (function () {
    function GitHubBlob() {
    }
    return GitHubBlob;
}());
exports.GitHubBlob = GitHubBlob;
/**
 * Typings representing symlink contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-symlink
 */
var GitHubSymlinkContents = /** @class */ (function (_super) {
    __extends(GitHubSymlinkContents, _super);
    function GitHubSymlinkContents() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GitHubSymlinkContents;
}(GitHubContents));
exports.GitHubSymlinkContents = GitHubSymlinkContents;
/**
 * Typings representing submodule contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-submodule
 */
var GitHubSubmoduleContents = /** @class */ (function (_super) {
    __extends(GitHubSubmoduleContents, _super);
    function GitHubSubmoduleContents() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GitHubSubmoduleContents;
}(GitHubContents));
exports.GitHubSubmoduleContents = GitHubSubmoduleContents;
/**
 * Typings representing repositories from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/#list-organization-repositories
 *
 * #### Notes
 *   This is incomplete.
 */
var GitHubRepo = /** @class */ (function () {
    function GitHubRepo() {
    }
    return GitHubRepo;
}());
exports.GitHubRepo = GitHubRepo;
