"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var application_1 = require("@jupyterlab/application");
var coreutils_1 = require("@jupyterlab/coreutils");
var docmanager_1 = require("@jupyterlab/docmanager");
var filebrowser_1 = require("@jupyterlab/filebrowser");
var contents_1 = require("./contents");
var browser_1 = require("./browser");
require("../style/index.css");
/**
 * GitHub filebrowser plugin state namespace.
 */
var NAMESPACE = 'github-filebrowser';
/**
 * The ID for the plugin.
 */
var PLUGIN_ID = '@jupyterlab/github:drive';
/**
 * The JupyterLab plugin for the GitHub Filebrowser.
 */
var fileBrowserPlugin = {
    id: PLUGIN_ID,
    requires: [docmanager_1.IDocumentManager, filebrowser_1.IFileBrowserFactory, application_1.ILayoutRestorer, coreutils_1.ISettingRegistry],
    activate: activateFileBrowser,
    autoStart: true
};
/**
 * Activate the file browser.
 */
function activateFileBrowser(app, manager, factory, restorer, settingRegistry) {
    var commands = app.commands;
    // Add the GitHub backend to the contents manager.
    var drive = new contents_1.GitHubDrive(app.docRegistry);
    manager.services.contents.addDrive(drive);
    var browser = factory.createFileBrowser(NAMESPACE, {
        commands: commands,
        driveName: drive.name
    });
    var gitHubBrowser = new browser_1.GitHubFileBrowser(browser, drive);
    gitHubBrowser.title.iconClass = 'jp-GitHub-tablogo';
    gitHubBrowser.id = 'github-file-browser';
    // Add the file browser widget to the application restorer.
    restorer.add(gitHubBrowser, NAMESPACE);
    app.shell.addToLeftArea(gitHubBrowser, { rank: 102 });
    var onSettingsUpdated = function (settings) {
        var baseUrl = settings.get('baseUrl').composite;
        gitHubBrowser.baseUrl = baseUrl || browser_1.DEFAULT_GITHUB_BASE_URL;
    };
    // Fetch the initial state of the settings.
    Promise.all([settingRegistry.load(PLUGIN_ID), app.restored])
        .then(function (_a) {
        var settings = _a[0];
        settings.changed.connect(onSettingsUpdated);
        onSettingsUpdated(settings);
        var defaultRepo = settings.get('defaultRepo').composite;
        if (defaultRepo) {
            browser.model.restored.then(function () {
                browser.model.cd("/" + defaultRepo);
            });
        }
    }).catch(function (reason) {
        console.error(reason.message);
    });
    return;
}
exports.default = fileBrowserPlugin;
